package com.vendor.burn.serial.workers;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.vendor.burn.analysis.TimeLogger;
import com.vendor.burn.commands.EraseCommand;
import com.vendor.burn.commands.INFOCommand;
import com.vendor.burn.commands.MWCommand;
import com.vendor.burn.commands.MmcPartCommand;
import com.vendor.burn.commands.ReadCommand;
import com.vendor.burn.commands.SFCommand;
import com.vendor.burn.commands.SerialCommand;
import com.vendor.burn.commands.WriteCommand;
import com.vendor.burn.jna.LibBootromByJNA;
import com.vendor.burn.jna.LibJTAGByJNA;
import com.vendor.burn.model.ChipID;
import com.vendor.burn.model.FileSystem;
import com.vendor.burn.model.FlashType;
import com.vendor.burn.model.PartitionItem;
import com.vendor.burn.model.PlatformType;
import com.vendor.burn.model.ProductLine;
import com.vendor.burn.model.TransferWay;
import com.vendor.burn.model.cmdline.BurnStatus;
import com.vendor.burn.model.config.BurnConfig;
import com.vendor.burn.model.config.PreferenceConfig;
import com.vendor.burn.model.devices.burners.CommonBurner;
import com.vendor.burn.model.devices.burners.EmmcBurner;
import com.vendor.burn.model.devices.unknown.UDFrameSetting;
import com.vendor.burn.model.devices.unknown.UDProperties;
import com.vendor.burn.model.devices.unknown.UnknownDevice;
import com.vendor.burn.model.event.EventType;
import com.vendor.burn.model.receive.ReceiveTimeOutException;
import com.vendor.burn.preferences.FastbootPreferences;
import com.vendor.burn.serial.workers.CallLibBootromWorker;
import com.vendor.burn.serial.workers.CallLibBurnWorker;
import com.vendor.burn.serial.workers.CallLibJTAGWorker;
import com.vendor.burn.serial.workers.CallLibUSBWorker;
import com.vendor.burn.serial.workers.EmmcPartitionBurnerWorker;
import com.vendor.burn.utilitily.FileUtils;
import com.vendor.burn.utilitily.ToolUtils;
import com.vendor.burn.views.FastbootView;
import java.io.BufferedInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.RandomAccessFile;
import java.util.ArrayList;
import java.util.List;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.SubMonitor;
import org.eclipse.jface.preference.IPreferenceStore;

public class CommonBurnerWorker extends EmmcPartitionBurnerWorker {
  public static final String FASTBOOT_NAME = "fastboot";
  
  public CommonBurnerWorker(CommonBurner burner) {
    super((EmmcBurner)burner);
  }
  
  public boolean burn(IProgressMonitor uimonitor, List<PartitionItem> parts) throws IOException, ReceiveTimeOutException {
    if (!ToolUtils.isCmdLine()) {
      String versionInfo = getVersionInfo("Burn By Partition");
      CallLibJTAGWorker.printDebugInfo(versionInfo);
    } 
    registerJnaFunction(uimonitor, 100);
    if (UnknownDevice.isOpenLightDebug())
      initLightState(); 
    long burnStartTime = System.currentTimeMillis();
    int selectedPartCount = getSelectedPartCount(parts);
    setProgressMonitor(uimonitor);
    getMonitor().getEvent().init(EventType.BURN);
    uimonitor.beginTask("Burn By Partition", 100 * selectedPartCount);
    if (FastbootView.isHiWing510())
      return burnByUnifyLibBurn(uimonitor, parts); 
    boolean result = burnByTransferWay(uimonitor, parts, selectedPartCount, new int[1]);
    long burnTotalTime = System.currentTimeMillis() - burnStartTime;
    String burnTotalTimeStr = calculateBurnTotalTime(burnTotalTime);
    getMonitor().getEvent().setTotalBurnTime(burnTotalTimeStr);
    printDebugTimeLogger(parts.get(0), burnTotalTime);
    return result;
  }
  
  private boolean burnByUnifyLibBurn(IProgressMonitor uimonitor, List<PartitionItem> parts) throws IOException, ReceiveTimeOutException {
    if (((PartitionItem)parts.get(0)).isChecked()) {
      if (!burnBootByUnifyLibBurn(uimonitor, ((PartitionItem)parts.get(0)).getFile().getCanonicalPath()))
        return false; 
    } else if (!burnBootByUnifyLibBurn(uimonitor, null)) {
      return false;
    } 
    for (int index = 1; index < parts.size(); index++) {
      PartitionItem partitionItem = parts.get(index);
      if (partitionItem.isChecked()) {
        if (!CallLibBurnWorker.downloadToFlash(partitionItem.getFile().getCanonicalPath(), partitionItem
            .getStart(), partitionItem.getLength())) {
          infoln("Failed to burn " + partitionItem.getName() + " partition!");
          return false;
        } 
        infoln("Partition " + partitionItem.getName() + " burn successfully!");
      } 
    } 
    resetByUnifyLibBurn();
    infoln("Partition burn successfully!");
    return true;
  }
  
  public boolean erase(IProgressMonitor uimonitor, List<PartitionItem> parts) throws IOException, ReceiveTimeOutException {
    setProgressMonitor(uimonitor);
    int selected = 0;
    for (PartitionItem partitionItem : parts) {
      if (partitionItem.isChecked())
        selected++; 
    } 
    int totalWork = (selected + 2) * 100;
    uimonitor.beginTask("", totalWork);
    uimonitor.setTaskName("Init Board");
    SubMonitor subProgressMonitor = SubMonitor.convert(uimonitor, "", 100);
    if (!ToolUtils.isCmdLine()) {
      String versionInfo = getVersionInfo("Erase Partitions");
      CallLibJTAGWorker.printDebugInfo(versionInfo);
    } 
    registerJnaFunction(uimonitor, 100);
    ArrayList<FlashType> hasFlashTypes = FlashType.getCurFlashTypes(parts);
    TransferWay curTransferWay = getBurner().getBurnContext().getTransferWay();
    if (FastbootView.isHiWing510())
      return eraseByUnifyLibBurn(uimonitor, parts); 
    boolean result = startbootForNoneNude(uimonitor, parts, hasFlashTypes, curTransferWay);
    if (!result)
      return result; 
    if (!sendSsdByPci(parts))
      return false; 
    uimonitor.worked(100);
    uimonitor.setTaskName("Erase Partitions");
    int partsSize = parts.size();
    for (int index = 0; index < partsSize && 
      !uimonitor.isCanceled(); index++) {
      PartitionItem part = parts.get(index);
      if (part.isChecked()) {
        getMonitor().highlight(part);
        String partitionName = (part.getName() == null) ? "" : part.getName();
        uimonitor.subTask("Partition: " + partitionName);
        if (curTransferWay == TransferWay.GPT) {
          if (part.getName() != null) {
            infoln("\nSend command:\terase: " + part.getName());
            if (!CallLibUSBWorker.eraseGptPartByUSB(part.getName(), 3000))
              return false; 
            infoln("Partition " + partitionName + " Erased successfully!");
          } 
        } else {
          FlashType flashType = part.getFlashType();
          if (flashType.toString().startsWith(FlashType.ufs.toString()) || FlashType.ssd == flashType || flashType
            .toString().startsWith(FlashType.emmc.toString())) {
            SerialCommand cmd = MmcPartCommand.getMmcPartConfCommand("writeBefore", flashType);
            if (cmd.getCommand() != null && !sendCommand(cmd))
              return false; 
            result = eraseEmmcPart(subProgressMonitor, part);
            if (result) {
              cmd = MmcPartCommand.getMmcPartConfCommand("writeAfter", flashType);
              if (cmd.getCommand() != null && !sendCommand(cmd))
                return false; 
            } 
          } else {
            if (ToolUtils.isJTagTransferMode(getBurner().getBurnContext().getTransferWay())) {
              new CallLibJTAGWorker(this.frameSetting, this.burner, subProgressMonitor);
              LibJTAGByJNA.instance.jtag_RegisterPrint(CallLibJTAGWorker.JTAGPRINTINFOCALLBACK);
              LibJTAGByJNA.instance.jtag_RegisterCancel(CallLibJTAGWorker.CANCELCALLBACK);
            } 
            result = eraseForNandorSpi(subProgressMonitor, partsSize, index, part);
          } 
        } 
        if (!result && !ToolUtils.isCmdLine()) {
          sendResetCommand();
          return result;
        } 
        uimonitor.worked(100);
      } 
    } 
    sendResetCommand();
    return true;
  }
  
  private boolean eraseByUnifyLibBurn(IProgressMonitor uimonitor, List<PartitionItem> parts) {
    if (!burnBootByUnifyLibBurn(uimonitor, null))
      return false; 
    for (int index = 0; index < parts.size(); index++) {
      PartitionItem partitionItem = parts.get(index);
      if (partitionItem.isChecked()) {
        if (!CallLibBurnWorker.eraseFlash(partitionItem.getStart(), partitionItem.getLength())) {
          infoln("Failed to erase " + partitionItem.getName() + " partition!");
          return false;
        } 
        infoln("Partition " + partitionItem.getName() + " erase successfully!");
      } 
    } 
    resetByUnifyLibBurn();
    infoln("Partition erase successfully!");
    return true;
  }
  
  public boolean eraseAll(IProgressMonitor uimonitor, List<PartitionItem> parts) throws IOException, ReceiveTimeOutException {
    setProgressMonitor(uimonitor);
    parts = ((CommonBurner)getBurner()).getChildren();
    int selected = 0;
    for (PartitionItem partitionItem : parts) {
      if (partitionItem.isChecked())
        selected++; 
    } 
    int totalWork = (selected + 2) * 100;
    uimonitor.beginTask("", totalWork);
    uimonitor.setTaskName("Init Board");
    String versionInfo = getVersionInfo("Erase all partitions");
    CallLibJTAGWorker.printDebugInfo(versionInfo);
    registerJnaFunction(uimonitor, 100);
    ArrayList<FlashType> hasFlashTypes = FlashType.getCurFlashTypes(parts);
    if (hasFlashTypes.size() == 0)
      hasFlashTypes = FlashType.getCurAllFlashTypes(parts); 
    TransferWay curTransferWay = getBurner().getBurnContext().getTransferWay();
    boolean result = true;
    result = startbootForNoneNude(uimonitor, parts, null, curTransferWay);
    if (!result)
      return result; 
    result = eraseAllFlash(uimonitor, parts, hasFlashTypes);
    if (result) {
      infoln("Erase all partitions successfully!");
    } else {
      returnError("Failed to Erase all partitions!");
      return false;
    } 
    uimonitor.worked(100);
    return result;
  }
  
  private boolean eraseAllFlash(IProgressMonitor uimonitor, List<PartitionItem> parts, ArrayList<FlashType> hasFlashTypes) throws IOException, ReceiveTimeOutException {
    if (!eraseBootMultiplePartition(parts.get(0)))
      return false; 
    if (isHasFlash(hasFlashTypes, FlashType.nand) && 
      !eraseNand(hasFlashTypes))
      return false; 
    if (isHasFlash(hasFlashTypes, FlashType.spi) && 
      !eraseAllSpi(hasFlashTypes, parts))
      return false; 
    if (isHasFlash(hasFlashTypes, FlashType.emmc) && 
      !eraseEmmcOrUfs(uimonitor, FlashType.emmc))
      return false; 
    if (isHasFlash(hasFlashTypes, FlashType.ufs) && 
      !eraseEmmcOrUfs(uimonitor, FlashType.ufs))
      return false; 
    return true;
  }
  
  public boolean upload(IProgressMonitor uimonitor, List<PartitionItem> parts) throws IOException, ReceiveTimeOutException {
    getMonitor().getEvent().init(EventType.UPLOAD);
    setProgressMonitor(uimonitor);
    int selected = 0;
    for (PartitionItem partitionItem : parts) {
      if (partitionItem.isChecked())
        selected++; 
    } 
    int totalWork = (selected + 2) * 100;
    uimonitor.beginTask("", totalWork);
    uimonitor.setTaskName("Init Board");
    String versionInfo = getVersionInfo("Uploading Partitions");
    CallLibJTAGWorker.printDebugInfo(versionInfo);
    if (FastbootView.isHiWing510())
      return uploadByUnifyLibBurn(uimonitor, parts); 
    registerJnaFunction(uimonitor, totalWork);
    ArrayList<FlashType> hasFlashTypes = FlashType.getCurFlashTypes(parts);
    TransferWay curTransferWay = getBurner().getBurnContext().getTransferWay();
    boolean result = startbootForNoneNude(uimonitor, parts, hasFlashTypes, curTransferWay);
    if (!result)
      return result; 
    if (!sendSsdByPci(parts))
      return false; 
    uimonitor.worked(100);
    uimonitor.setTaskName("Setting Up Network");
    TransferWay transferWay = getBurner().getBurnContext().getTransferWay();
    if (isNeedSetupNet(transferWay) && 
      !setupNetwork(transferWay)) {
      returnError("Failed to setup network!");
      return false;
    } 
    uimonitor.setTaskName("Uploading Partitions");
    int partsSize = parts.size();
    uimonitor.beginTask("Uploading Partitions", selected * 100);
    for (int partIndex = 0; partIndex < parts.size(); partIndex++) {
      PartitionItem partition = parts.get(partIndex);
      if (partition.isChecked()) {
        FileSystem uploadFileSystem = partition.getFileSystem();
        String start = Long.toHexString(partition.getStart());
        String length = Long.toHexString(partition.getLength());
        FlashType flashType = partition.getFlashType();
        File file = partition.getFile();
        if (flashType.toString().startsWith(FlashType.ufs.toString()) || FlashType.ssd == flashType || flashType
          .toString().startsWith(FlashType.emmc.toString())) {
          result = uploadPartForEmmc(uimonitor, partsSize, partIndex, partition);
        } else {
          setFlashType(partition.getFlashType());
          result = upload(uimonitor, file, uploadFileSystem, start, length, false, ChipID.chip0);
        } 
        if (!result) {
          sendResetCommand();
          return result;
        } 
        selected--;
      } 
    } 
    sendResetCommand();
    uimonitor.worked(100);
    return true;
  }
  
  private boolean uploadByUnifyLibBurn(IProgressMonitor uimonitor, List<PartitionItem> parts) {
    if (!burnBootByUnifyLibBurn(uimonitor, null))
      return false; 
    for (int index = 0; index < parts.size(); index++) {
      PartitionItem partitionItem = parts.get(index);
      if (partitionItem.isChecked()) {
        String filePath = null;
        try {
          filePath = partitionItem.getFile().getCanonicalPath();
        } catch (IOException e) {
          infoln("Failed to get " + partitionItem.getName() + " file path!");
          return false;
        } 
        if (!CallLibBurnWorker.uploadFile(partitionItem.getStart(), partitionItem.getLength(), filePath)) {
          infoln("Failed to upload " + partitionItem.getName() + " partition!");
          return false;
        } 
        infoln("Partition " + partitionItem.getName() + " upload successfully!");
      } 
    } 
    resetByUnifyLibBurn();
    infoln("Partition upload successfully!");
    return true;
  }
  
  public boolean createImage(IProgressMonitor uiMonitor, File file, List<PartitionItem> parts, boolean call) {
    return super.createImage(uiMonitor, file, parts, call);
  }
  
  private boolean uploadPartForEmmc(IProgressMonitor uiMonitor, int partsSize, int partIndex, PartitionItem partition) throws IOException, ReceiveTimeOutException {
    String partitionName = (partition.getName() == null) ? "" : partition.getName();
    uiMonitor.subTask("Parition:" + partitionName);
    getMonitor().highlight(partition);
    File file = partition.getFile();
    long start = partition.getStart();
    long length = partition.getLength();
    FlashType flashType = partition.getFlashType();
    if (length == -1L && partIndex == partsSize - 1) {
      long neMMCCapacity = geteMMCSpaceSize(flashType);
      if (0L == neMMCCapacity) {
        warningln("Failed to get eMMC capacity!");
        return false;
      } 
      length = neMMCCapacity - start;
      String errorType = "All eMMC remain space ";
      if (FlashType.fuzzyCompareFlash(flashType, FlashType.ufs))
        errorType = "All ufs remain space "; 
      warningln(errorType + errorType + " Bytes allotted to last partition!");
    } 
    long uploadAddress = start / 512L;
    long uploadLength = length / 512L;
    int partCount = (int)(length / 16777216L);
    if (length % 16777216L != 0L)
      partCount++; 
    TransferWay transferWay = getBurner().getBurnContext().getTransferWay();
    File tmpFile = null;
    try {
      tmpFile = createFile(file.getPath() + ".tmp", partitionName);
      if (tmpFile == null) {
        returnError("Failed to upload " + partitionName + " partition!");
        return false;
      } 
      if (transferWay != TransferWay.UsbAndSerial && 
        !FastbootView.isSupportUsbNonNude(transferWay))
        switchTFTPDownloadHome(tmpFile); 
      if (partCount == 1) {
        SerialCommand cmd = MmcPartCommand.getMmcPartConfCommand("writeBefore", flashType);
        if (cmd.getCommand() != null && !sendCommand(cmd))
          return false; 
        boolean result = sendCommand((SerialCommand)ReadCommand.readMMC_0_Destination_(getHexStartAddress(), 
              Long.toHexString(uploadAddress), Long.toHexString(uploadLength), flashType));
        if (result)
          result = uploadByTrans(uiMonitor, length, tmpFile); 
        if (result) {
          cmd = MmcPartCommand.getMmcPartConfCommand("writeAfter", flashType);
          if (cmd.getCommand() != null && !sendCommand(cmd))
            return false; 
        } 
        if (!result) {
          returnError("Failed to upload " + partitionName + " partition!");
          return false;
        } 
        uiMonitor.worked(100);
        infoln("Partition uploaded successfully!");
      } else {
        Double historyProgress = Double.valueOf(0.0D);
        for (int i = 0; i < partCount; i++) {
          File partFile = createFile(file.getPath() + ".part" + file.getPath(), partitionName);
          if (null == partFile)
            return false; 
          long partUploadAddress = uploadAddress + i * 32768L;
          long partUploadRealLength = 0L;
          long partUploadLength = 0L;
          if (i == partCount - 1) {
            partUploadRealLength = length - i * 16777216L;
            partUploadLength = uploadLength - i * 32768L;
          } else {
            partUploadRealLength = 16777216L;
            partUploadLength = 32768L;
          } 
          boolean result = sendCommand((SerialCommand)ReadCommand.readMMC_0_Destination_(getHexStartAddress(), 
                Long.toHexString(partUploadAddress), Long.toHexString(partUploadLength), flashType));
          if (result)
            result = uploadByTrans(uiMonitor, partUploadRealLength, partFile); 
          if (!result) {
            returnError("Failed to upload " + partitionName + " partition!");
            return false;
          } 
          infoln("Partition part " + i + " uploaded successfully!");
          BufferedInputStream bis = null;
          RandomAccessFile raf = null;
          try {
            bis = new BufferedInputStream(new FileInputStream(partFile));
            raf = new RandomAccessFile(tmpFile, "rw");
            raf.seek(tmpFile.length());
            byte[] buffer = new byte[512];
            int readSize = 0;
            while ((readSize = bis.read(buffer, 0, buffer.length)) != -1)
              raf.write(buffer, 0, readSize); 
          } catch (IOException iOException) {
          
          } finally {
            try {
              if (raf != null)
                raf.close(); 
            } catch (IOException iOException) {}
            try {
              if (bis != null)
                bis.close(); 
            } catch (IOException iOException) {}
            partFile.deleteOnExit();
            deleteTempFile(partFile);
          } 
          Double index = Double.valueOf((i + 1));
          Double count = Double.valueOf(partCount);
          Double progress = Double.valueOf(index.doubleValue() / count.doubleValue() * 100.0D);
          if (progress.doubleValue() - historyProgress.doubleValue() > 1.0D) {
            uiMonitor.worked(1);
            Double double_ = historyProgress;
            historyProgress = Double.valueOf(historyProgress.doubleValue() + 1.0D);
          } 
        } 
        uiMonitor.worked(100);
      } 
      if (!FileUtils.copy(uiMonitor, tmpFile, file)) {
        returnError("Cannot operate on the destination file!");
        return false;
      } 
    } finally {
      if (tmpFile != null)
        tmpFile.deleteOnExit(); 
      deleteTempFile(tmpFile);
    } 
    if (transferWay != TransferWay.UsbAndSerial && 
      !FastbootView.isSupportUsbNonNude(transferWay))
      switchTFTPDownloadHome(file); 
    uiMonitor.worked(100);
    return true;
  }
  
  private File createFile(String path, String partitionName) throws IOException {
    File partFile = new File(path);
    if (partFile.exists() && 
      !partFile.delete()) {
      returnError("Cannot operate on temp file. Uplodaing will be stoped.");
      return null;
    } 
    if (!partFile.createNewFile()) {
      returnError("Failed to upload " + partitionName + " partition!");
      return null;
    } 
    return partFile;
  }
  
  private boolean eraseEmmcOrUfs(IProgressMonitor uiMonitor, FlashType flashType) throws IOException, ReceiveTimeOutException {
    boolean result = false;
    long neMMCCapacity = geteMMCSpaceSize(flashType);
    if (0L == neMMCCapacity) {
      warningln("Failed to get eMMC capacity!");
      return false;
    } 
    long erasePartitionLen = neMMCCapacity / 512L * 512L;
    if (erasePartitionLen % 512L != 0L)
      erasePartitionLen += 512L; 
    int length = 134217728;
    UDProperties properties = ((UnknownDevice)this.burner.getBurnContext().getDeviceSetting()).getProperties();
    String boardType = properties.queryForString("TYPE");
    if (boardType != null && boardType.equalsIgnoreCase("CAM"))
      length = 33554432; 
    long count = erasePartitionLen / length;
    long eraseLenSector = erasePartitionLen / 512L;
    uiMonitor.beginTask("", (int)(count * 10L) + 20);
    if (FastbootPreferences.isDiskFormatting()) {
      result = sendCommand((SerialCommand)EraseCommand.eraseEmmc(Long.toHexString(0L), Long.toHexString(eraseLenSector), 
            Long.toHexString(neMMCCapacity)));
    } else {
      long partLength = length;
      partLength /= 512L;
      String fillData = null;
      if (ToolUtils.isCmdLine()) {
        fillData = String.valueOf(PreferenceConfig.getImgFillData());
      } else {
        IPreferenceStore preferences = FastbootPreferences.getPreferenceStore();
        fillData = preferences.getString("vendor.burn.config.imageFill");
      } 
      long address = 0L;
      while (eraseLenSector > 0L && 
        !uiMonitor.isCanceled()) {
        if (eraseLenSector >= (length / 512)) {
          MWCommand mWCommand = null;
          if (fillData.equals("0xFF")) {
            long writeSize = partLength * 512L;
            if (FlashType.fuzzyCompareFlash(flashType, FlashType.ufs))
              writeSize = partLength * 4096L; 
            mWCommand = MWCommand.mwAddress(getHexStartAddress(), Long.toHexString(writeSize));
          } else {
            mWCommand = MWCommand.mwAddress(getHexStartAddress(), Long.toHexString(partLength * 512L));
          } 
          result = sendCommand((SerialCommand)mWCommand);
          uiMonitor.worked(5);
          for (int i = 0; i < count && 
            !uiMonitor.isCanceled(); i++) {
            WriteCommand writeCommand = WriteCommand.writeeMMC(flashType, getHexStartAddress(), Long.toHexString(address), 
                Long.toHexString(partLength));
            result = sendCommand((SerialCommand)writeCommand);
            address += partLength;
            uiMonitor.worked(10);
            eraseLenSector -= partLength;
          } 
          continue;
        } 
        MWCommand memsetCommand = MWCommand.mwAddress(getHexStartAddress(), Long.toHexString(eraseLenSector * 512L));
        result = sendCommand((SerialCommand)memsetCommand);
        uiMonitor.worked(5);
        WriteCommand burnCommand = WriteCommand.writeeMMC(flashType, getHexStartAddress(), Long.toHexString(address), 
            Long.toHexString(eraseLenSector));
        result &= sendCommand((SerialCommand)burnCommand);
        address += eraseLenSector;
        uiMonitor.worked(10);
        eraseLenSector = 0L;
      } 
    } 
    return result;
  }
  
  private boolean eraseAllSpi(ArrayList<FlashType> hasFlashTypes, List<PartitionItem> parts) throws IOException, ReceiveTimeOutException {
    boolean result = false;
    ArrayList<ChipID> existChipIDInParts = ChipID.getChipIDInParts(parts);
    if (existChipIDInParts != null)
      for (ChipID chipID : existChipIDInParts) {
        result = sendCommand((SerialCommand)SFCommand.getInstance(chipID));
        long spiSpaceSize = getSpiSpaceSize();
        if (spiSpaceSize != 0L && spiSpaceSize > 0L && 
          result)
          result = sendCommand((SerialCommand)EraseCommand.erase(FlashType.spi, Long.toHexString(0L), 
                Long.toHexString(spiSpaceSize))); 
      }  
    return result;
  }
  
  private boolean eraseNand(ArrayList<FlashType> hasFlashTypes) throws IOException, ReceiveTimeOutException {
    boolean result = false;
    long nandSpaceSize = getNandSpaceSize();
    if (nandSpaceSize != 0L && nandSpaceSize > 0L) {
      EraseCommand eraseCommand = eraseAllCommand(nandSpaceSize, this.burner.getBurnContext().getDeviceSetting());
      result = sendCommand((SerialCommand)eraseCommand);
    } 
    return result;
  }
  
  private boolean eraseEmmcPart(SubMonitor subProgressMonitor, PartitionItem part) throws IOException, ReceiveTimeOutException {
    boolean bRet = true;
    long startSector = part.getStart() / 512L;
    long partitionLen = part.getLength();
    int length = 134217728;
    UDProperties properties = ((UnknownDevice)this.burner.getBurnContext().getDeviceSetting()).getProperties();
    String boardType = properties.queryForString("TYPE");
    if (boardType != null && boardType.equalsIgnoreCase("CAM"))
      length = 33554432; 
    long erasePartitionLen = partitionLen / 512L * 512L;
    if (erasePartitionLen % 512L != 0L)
      erasePartitionLen += 512L; 
    long count = erasePartitionLen / length;
    long eraseLenSector = erasePartitionLen / 512L;
    long partLength = length;
    partLength /= 512L;
    FlashType flashType = part.getFlashType();
    if (FlashType.fuzzyCompareFlash(flashType, FlashType.emmc))
      flashType = FlashType.emmc; 
    if (FlashType.ufs1.equals(flashType))
      flashType = FlashType.ufs; 
    while (eraseLenSector > 0L && 
      !subProgressMonitor.isCanceled()) {
      if (eraseLenSector >= (length / 512)) {
        MWCommand mWCommand = MWCommand.mwAddress(getHexStartAddress(), Long.toHexString(partLength * 512L));
        bRet = sendCommand((SerialCommand)mWCommand);
        if (!bRet)
          return false; 
        for (int i = 0; i < count && 
          !subProgressMonitor.isCanceled(); i++) {
          WriteCommand writeCommand = WriteCommand.writeeMMC(part.getFlashType(), getHexStartAddress(), 
              Long.toHexString(startSector), Long.toHexString(partLength));
          bRet = sendCommand((SerialCommand)writeCommand);
          if (!bRet)
            return false; 
          startSector += partLength;
          eraseLenSector -= partLength;
        } 
        continue;
      } 
      MWCommand memsetCommand = MWCommand.mwAddress(getHexStartAddress(), Long.toHexString(eraseLenSector * 512L));
      bRet = sendCommand((SerialCommand)memsetCommand);
      if (!bRet)
        return false; 
      WriteCommand burnCommand = WriteCommand.writeeMMC(part.getFlashType(), getHexStartAddress(), Long.toHexString(startSector), 
          Long.toHexString(eraseLenSector));
      bRet = sendCommand((SerialCommand)burnCommand);
      if (!bRet)
        return false; 
      startSector += eraseLenSector;
      eraseLenSector = 0L;
    } 
    return true;
  }
  
  private boolean burnReceivePart(String partName, List<PartitionItem> parts) {
    PartitionItem burnPart = null;
    for (PartitionItem part : parts) {
      if (partName.equals(part.getName())) {
        burnPart = part;
        break;
      } 
    } 
    if (burnPart == null) {
      returnError("partition " + partName + " is not found in the burning list.");
      return false;
    } 
    infoln("\nSend command:\t" + burnPart.getName());
    if (!CallLibUSBWorker.downloadFileGptByUsb(burnPart.getFile()))
      return false; 
    return true;
  }
  
  private boolean burnEachPartForGpt(IProgressMonitor uimonitor, List<PartitionItem> parts) throws IOException, ReceiveTimeOutException {
    for (PartitionItem part : parts) {
      if (part.getName().equalsIgnoreCase("gpt")) {
        infoln("\nSend command:\tDownloading File : gpt");
        if (!CallLibUSBWorker.downloadFileGptByUsb(part.getFile()))
          return false; 
        break;
      } 
    } 
    for (PartitionItem part : parts) {
      if (part.getName().equalsIgnoreCase("bootargs")) {
        infoln("\nSend command:\tDownloading File : bootargs");
        if (!CallLibUSBWorker.downloadFileGptByUsb(part.getFile()))
          return false; 
        break;
      } 
    } 
    INFOCommand command = INFOCommand.getInfoGpt();
    infoln("\nSend command:\t" + command.getCommand());
    if (!sendCmdByTrans(command.getCommand(), command.getTimeout()))
      return false; 
    StringBuilder temp = new StringBuilder();
    if (!receiveBytesByUsb(temp, 512, TransferWay.GPT))
      return false; 
    String recvStr = temp.toString();
    String recvResult = recvStr.substring(0, 4);
    if (!recvResult.equalsIgnoreCase("info")) {
      infoln("getinfo gpt failed");
      return false;
    } 
    String recvParts = recvStr.substring(4, recvStr.length());
    String[] partsName = recvParts.split("/");
    for (int i = 0; i < partsName.length; i++)
      burnReceivePart(partsName[i], parts); 
    return true;
  }
  
  public boolean burnByTransferWay(IProgressMonitor uimonitor, List<PartitionItem> parts, int selectedPartCount, int[] errorCode) throws IOException, ReceiveTimeOutException {
    if (getUimonitor() == null)
      setProgressMonitor(uimonitor); 
    createTimer();
    registerJnaFunction(uimonitor, 100);
    ArrayList<FlashType> hasFlashTypes = FlashType.getCurFlashTypes(parts);
    PartitionItem fastboot = parts.get(0);
    boolean result = true;
    TransferWay curTransferWay = getBurner().getBurnContext().getTransferWay();
    if (curTransferWay == TransferWay.Uart2Compress) {
      result = burnByUart2Compress(uimonitor, parts, hasFlashTypes, fastboot, curTransferWay);
      if (!result)
        return result; 
      sendCommandToSetMac();
      String resetCommand = "reset";
      sendCommandNoReturnValue(resetCommand);
    } else if (curTransferWay == TransferWay.Usb2I2c || curTransferWay == TransferWay.I2CBootrom) {
      this.i2cTimeLogger = new TimeLogger();
      this.flashTimeLogger = new TimeLogger();
      this.resetTimeLogger = new TimeLogger();
      result = burnByI2c(uimonitor, parts, fastboot, result, hasFlashTypes, selectedPartCount);
      sendCommandToSetMac();
      if (ToolUtils.isDebugOn()) {
        getMonitor().println(this.i2cTimeLogger.exportLog("I2C transmission time"));
        getMonitor().println(this.flashTimeLogger.exportLog("Burning Flash of time"));
        getMonitor().println(this.resetTimeLogger.exportLog("Reset time"));
      } 
      if (!result)
        return result; 
    } else {
      if (FastbootView.isChipBranchSeries5())
        return burnByOneImage(uimonitor, parts, errorCode); 
      result = startBootForBurn(uimonitor, parts, selectedPartCount, hasFlashTypes, fastboot, curTransferWay);
      if (!result) {
        errorCode[0] = BurnStatus.BURN_BOOT_FAILED.getErrorCode();
        return result;
      } 
      uimonitor.setTaskName("Burning Partitions");
      int partsSize = parts.size();
      startZipThread(uimonitor, parts, hasFlashTypes, curTransferWay);
      boolean isPci = isPci(parts);
      for (int index = 1; index < partsSize; index++) {
        PartitionItem partitionItem = parts.get(index);
        FlashType flashType = partitionItem.getFlashType();
        if (FlashType.isEmmcOrUfs(flashType) || flashType == FlashType.ssd) {
          if (flashType == FlashType.ssd && isPci) {
            if (!sendSsdByPci(parts))
              return false; 
            isPci = false;
          } 
          SerialCommand cmd = MmcPartCommand.getMmcPartConfCommand("writeBefore", flashType);
          if (partitionItem.isChecked() && cmd.getCommand() != null && !sendCommand(cmd)) {
            errorCode[0] = BurnStatus.BURN_PARTITION_FAILED.getErrorCode();
            return false;
          } 
          result = burnEachPartForEmmc(uimonitor, parts, index);
          if (result) {
            cmd = MmcPartCommand.getMmcPartConfCommand("writeAfter", flashType);
            if (partitionItem.isChecked() && cmd.getCommand() != null && !sendCommand(cmd)) {
              errorCode[0] = BurnStatus.BURN_PARTITION_FAILED.getErrorCode();
              return false;
            } 
          } 
        } else {
          result = burnEachPartForNandOrSpi(uimonitor, parts, index);
        } 
        if (!result) {
          errorCode[0] = BurnStatus.BURN_PARTITION_FAILED.getErrorCode();
          return result;
        } 
      } 
      sendCommandToSetMac();
      sendResetCommand();
    } 
    infoln("Partition burnt completed!");
    return result;
  }
  
  private boolean burnByOneImage(IProgressMonitor uimonitor, List<PartitionItem> parts, int[] errorCode) {
    SubMonitor subProgressMonitor = SubMonitor.convert(uimonitor, "", 100);
    subProgressMonitor.beginTask("", 100);
    subProgressMonitor.setTaskName("Downloading Boot");
    new CallLibBootromWorker(this.frameSetting, this.burner, subProgressMonitor);
    LibBootromByJNA.instance.RegisterPrint(CallLibBootromWorker.callback);
    LibBootromByJNA.instance.RegisterCancel(CallLibBootromWorker.callbackCancel);
    CallLibBootromWorker.setChipType(FastbootView.getDepartmentNumber(this.burner), 
        FastbootView.getChipType(this.burner));
    String filePath = null;
    try {
      filePath = ((PartitionItem)parts.get(0)).getFile().getCanonicalPath();
    } catch (IOException e) {
      infoln("An exception occurs on getCanonicalPath.\n");
      return false;
    } 
    String[] fileInfo = CallLibBootromWorker.resolveAllinoneImage(filePath);
    if (fileInfo.length <= 0) {
      infoln("\n****************************************************************************");
      infoln("* Incorrect image format.        *");
      infoln("****************************************************************************\n");
      return false;
    } 
    long comFd = getComFd(parts, errorCode);
    if (comFd < 0L)
      return false; 
    CallLibBootromWorker.setTypeFrameTimeout(BurnConfig.getBeforeBurningDelayTime());
    if (!CallLibBootromWorker.bootromBootDownload(comFd, filePath)) {
      errorCode[0] = BurnStatus.BURN_BOOT_FAILED.getErrorCode();
      printErrorLog("upgrade");
      return false;
    } 
    if (!CallLibBootromWorker.sendReset(comFd)) {
      errorCode[0] = BurnStatus.BURN_BOOT_FAILED.getErrorCode();
      printErrorLog("reset");
      return false;
    } 
    subProgressMonitor.done();
    infoln("Burn Successful!");
    return true;
  }
  
  private long getComFd(List<PartitionItem> parts, int[] errorCode) {
    long comFd = -1L;
    if (CommonBurner.isSocketTransfer) {
      boolean isSuccess = CallLibBootromWorker.createSerialPortServer(this.boardConfig.getSerialServerIp(), this.boardConfig
          .getSerialServerPort());
      if (!isSuccess) {
        printBurnLog(false, String.valueOf(this.boardConfig.getSerialServerPort()));
        errorCode[0] = BurnStatus.INIT_TRANSFER_WAY_FAILED.getErrorCode();
        return comFd;
      } 
      printBurnLog(true, String.valueOf(this.boardConfig.getSerialServerPort()));
      comFd = CallLibBootromWorker.getSocketFd();
      if (!sendUserNameAndPassWord(this.boardConfig, false)) {
        errorCode[0] = BurnStatus.INIT_TRANSFER_WAY_FAILED.getErrorCode();
        return comFd;
      } 
    } else {
      if (this.burner instanceof com.vendor.burn.model.devices.burners.AbstractBurner) {
        String portName = this.burner.getBurnContext().getLocalConfig().getComPort();
        if (!openSerialComm(this.burner.getBurnContext().getTransferWay())) {
          errorCode[0] = BurnStatus.INIT_TRANSFER_WAY_FAILED.getErrorCode();
          printBurnLog(false, portName);
          return comFd;
        } 
        printBurnLog(true, portName);
      } 
      comFd = CallLibBootromWorker.getComFd();
    } 
    return comFd;
  }
  
  private boolean sendSsdByPci(List<PartitionItem> parts) throws IOException, ReceiveTimeOutException {
    boolean isExist = false;
    for (int index = 1; index < parts.size(); index++) {
      FlashType flashType = ((PartitionItem)parts.get(index)).getFlashType();
      if (flashType == FlashType.ssd)
        isExist = true; 
    } 
    if (isExist) {
      if (!sendCommand("pci enum"))
        return false; 
      if (!sendCommand("nvme scan"))
        return false; 
    } 
    return true;
  }
  
  private boolean isPci(List<PartitionItem> parts) {
    boolean isPci = false;
    for (int index = 1; index < parts.size(); index++) {
      PartitionItem partitionItem = parts.get(index);
      if (partitionItem.getFlashType() == FlashType.ssd && partitionItem.isChecked())
        isPci = true; 
    } 
    return isPci;
  }
  
  private boolean startBootForBurn(IProgressMonitor uimonitor, List<PartitionItem> parts, int selectedPartCount, ArrayList<FlashType> hasFlashTypes, PartitionItem fastboot, TransferWay curTransferWay) throws IOException, ReceiveTimeOutException {
    if (fastboot.isChecked())
      uimonitor.setTaskName("Burning Fastboot Partition"); 
    FastbootView.setStartNetwork(true);
    FlashType bootFlashType = fastboot.getFlashType();
    if (FlashType.isEmmcOrUfs(bootFlashType)) {
      int emmcType = ((UnknownDevice)this.burner.getBurnContext().getDeviceSetting()).getEmmcType();
      if (!burnbootForEmmc(curTransferWay, emmcType, fastboot, parts))
        return false; 
    } else if (!burnbootForNandOrSpi(uimonitor, parts, selectedPartCount, hasFlashTypes, fastboot, curTransferWay)) {
      return false;
    } 
    if (FastbootView.isStartNetwork() && 
      !needSetupNetwork(curTransferWay))
      return false; 
    if (fastboot.getFile() != null)
      this.burnBootTimeLogger.logEnd(); 
    return true;
  }
  
  private void startZipThread(IProgressMonitor uimonitor, List<PartitionItem> parts, ArrayList<FlashType> hasFlashTypes, TransferWay curTransferWay) throws IOException, ReceiveTimeOutException {
    boolean hasEmmcFlash = (isHasFlash(hasFlashTypes, FlashType.emmc) || isHasFlash(hasFlashTypes, FlashType.ufs) || isHasFlash(hasFlashTypes, FlashType.ssd));
    if (hasEmmcFlash) {
      long ddrFreeBaseAddr = 0L;
      long ddrFreeSize = 0L;
      try {
        String ddrFreeSizeStr;
        if (curTransferWay == TransferWay.UDP) {
          ddrFreeSizeStr = this.udpDdrFreeSizeStr;
        } else {
          ddrFreeSizeStr = getDDRFreeParam();
        } 
        ddrFreeSize = parseLong(getDDRFreeParam("size:", ddrFreeSizeStr, curTransferWay));
        ddrFreeBaseAddr = parseLong(getDDRFreeParam("baseaddr:", ddrFreeSizeStr, curTransferWay));
      } catch (IOException iOException) {
      
      } catch (ReceiveTimeOutException receiveTimeOutException) {}
      if (this.frameSetting instanceof UDFrameSetting && ProductLine.PRODUCTLINE.CAM != ToolUtils.getProductLine()) {
        UDFrameSetting udFrameSetting = (UDFrameSetting)this.frameSetting;
        udFrameSetting.setDdrInitAddrByLibBootrom(ddrFreeBaseAddr);
      } 
      debugPrintln("ddrFree: " + ddrFreeSize);
      debugPrintln("baseAddr: " + ddrFreeBaseAddr);
      this.useCompress = getTempDivisionSize(ddrFreeSize);
      runMakeZipThread(uimonitor, parts, this.useCompress);
    } 
  }
  
  private boolean eraseForNandorSpi(SubMonitor subProgressMonitor, int partsSize, int index, PartitionItem part) throws IOException, ReceiveTimeOutException {
    boolean bRet = true;
    String partitionName = part.getName();
    FlashType flashType = part.getFlashType();
    long partStart = part.getStart();
    long partLength = part.getLength();
    long startSector = partStart / 512L;
    if (index == partsSize - 1 && partLength == -1L) {
      partLength = getLastPartitionLen(part, partStart, partLength, flashType, startSector);
      if (partLength == -1L)
        return false; 
    } 
    if (FlashType.spi == flashType)
      bRet = sendCommand((SerialCommand)SFCommand.getInstance(ChipID.chip0)); 
    if (bRet)
      bRet = sendCommand((SerialCommand)EraseCommand.erase(flashType, Long.toHexString(partStart), Long.toHexString(partLength))); 
    if (bRet) {
      infoln("Partition " + partitionName + " Erased successfully!");
    } else {
      returnError("Failed to Erase " + partitionName + " Partition!");
      return false;
    } 
    subProgressMonitor.worked(100);
    return bRet;
  }
  
  private boolean startbootForNoneNude(IProgressMonitor uimonitor, List<PartitionItem> parts, ArrayList<FlashType> hasFlashTypes, TransferWay curTransferWay) throws IOException, ReceiveTimeOutException {
    PartitionItem fastboot = parts.get(0);
    FlashType bootFlashType = fastboot.getFlashType();
    TransferWay transferWay = getBurner().getBurnContext().getTransferWay();
    if (transferWay == TransferWay.USBNonNude) {
      if (!openTransmissionMode(transferWay, this.boardConfig))
        return false; 
      getDdrFreeBaseAddr(transferWay);
      if (bootFlashType == FlashType.nand || bootFlashType == FlashType.spi)
        if (loadVersionInfo(this.burner.getBurnContext().getTransferWay())) {
          loadBlockSizes(hasFlashTypes, ChipID.chip0, false);
        } else if (this.burner.getBurnContext().getPlatformType() == PlatformType.CA) {
          loadBlockSizes(hasFlashTypes, ChipID.chip0, false);
          warningln("Warning: Failed to load version info!");
        } else {
          returnError("Failed to load version info!");
          return false;
        }  
    } else {
      boolean result = prepareToBurn(false, EventType.ERASE, hasFlashTypes);
      if (!result)
        return false; 
    } 
    return true;
  }
  
  private boolean isHasFlash(ArrayList<FlashType> hasFlashTypes, FlashType curFlashType) {
    for (FlashType flashType : hasFlashTypes) {
      if (FlashType.fuzzyCompareFlash(flashType, curFlashType))
        return true; 
    } 
    return false;
  }
  
  public int getSelectedPartCount(List<PartitionItem> parts) {
    int selectedPartCount = 0;
    for (PartitionItem partitionItem : parts) {
      if (partitionItem.isChecked())
        selectedPartCount++; 
    } 
    return selectedPartCount;
  }
  
  private void createTimer() {
    this.burnBootTimeLogger = new TimeLogger();
    this.tftpTimeLogger = new TimeLogger();
    this.burnTimeLogger = new TimeLogger();
    this.waitZipTimeLogger = new TimeLogger();
    this.zipAndPageTimeLogger = new TimeLogger();
    this.unZipTimeLogger = new TimeLogger();
    this.spellingSparseFileLogger = new TimeLogger();
    this.crcLogger = new TimeLogger();
  }
  
  public boolean burnZipByTransferWay(IProgressMonitor uimonitor, List<PartitionItem> parts, int selectedPartCount, int[] errorCode) throws IOException, ReceiveTimeOutException {
    if (getUimonitor() == null)
      setProgressMonitor(uimonitor); 
    createTimer();
    if (!ToolUtils.isCmdLine())
      registerJnaFunction(uimonitor, 100); 
    ArrayList<FlashType> hasFlashTypes = FlashType.getCurFlashTypes(parts);
    PartitionItem fastboot = parts.get(0);
    boolean result = true;
    TransferWay curTransferWay = getBurner().getBurnContext().getTransferWay();
    if (curTransferWay == TransferWay.Uart2Compress) {
      result = burnByUart2Compress(uimonitor, parts, hasFlashTypes, fastboot, curTransferWay);
      if (!result)
        return result; 
      sendCommandToSetMac();
      String resetCommand = "reset";
      sendCommandNoReturnValue(resetCommand);
    } else if (curTransferWay == TransferWay.Usb2I2c || curTransferWay == TransferWay.I2CBootrom) {
      this.i2cTimeLogger = new TimeLogger();
      this.flashTimeLogger = new TimeLogger();
      this.resetTimeLogger = new TimeLogger();
      result = burnByI2c(uimonitor, parts, fastboot, result, hasFlashTypes, selectedPartCount);
      sendCommandToSetMac();
      if (ToolUtils.isDebugOn()) {
        getMonitor().println(this.i2cTimeLogger.exportLog("I2C transmission time"));
        getMonitor().println(this.flashTimeLogger.exportLog("Burning Flash of time"));
        getMonitor().println(this.resetTimeLogger.exportLog("Reset time"));
      } 
      if (!result)
        return result; 
    } else if (curTransferWay == TransferWay.GPT) {
      result = startBootForBurn(uimonitor, parts, selectedPartCount, hasFlashTypes, fastboot, curTransferWay);
      if (!result) {
        errorCode[0] = BurnStatus.BURN_BOOT_FAILED.getErrorCode();
        return result;
      } 
      if (!burnEachPartForGpt(uimonitor, parts)) {
        errorCode[0] = BurnStatus.BURN_PARTITION_FAILED.getErrorCode();
        return false;
      } 
      sendCommandToSetMac();
    } else {
      result = startBootForBurn(uimonitor, parts, selectedPartCount, hasFlashTypes, fastboot, curTransferWay);
      if (!result) {
        errorCode[0] = BurnStatus.BURN_BOOT_FAILED.getErrorCode();
        return result;
      } 
      uimonitor.setTaskName("Burning Partitions");
      int partsSize = parts.size();
      boolean hasEmmcFlash = (isHasFlash(hasFlashTypes, FlashType.emmc) || isHasFlash(hasFlashTypes, FlashType.ufs) || isHasFlash(hasFlashTypes, FlashType.ssd));
      if (hasEmmcFlash) {
        long ddrFreeBaseAddr = 0L;
        long ddrFreeSize = 0L;
        try {
          String ddrFreeSizeStr;
          if (curTransferWay == TransferWay.UDP) {
            ddrFreeSizeStr = this.udpDdrFreeSizeStr;
          } else {
            ddrFreeSizeStr = getDDRFreeParam();
          } 
          ddrFreeSize = parseLong(getDDRFreeParam("size:", ddrFreeSizeStr, curTransferWay));
          ddrFreeBaseAddr = parseLong(getDDRFreeParam("baseaddr:", ddrFreeSizeStr, curTransferWay));
        } catch (IOException iOException) {
        
        } catch (ReceiveTimeOutException receiveTimeOutException) {}
        if (this.frameSetting instanceof UDFrameSetting && ProductLine.PRODUCTLINE.CAM != ToolUtils.getProductLine()) {
          UDFrameSetting udFrameSetting = (UDFrameSetting)this.frameSetting;
          udFrameSetting.setDdrInitAddrByLibBootrom(ddrFreeBaseAddr);
        } 
        debugPrintln("ddrFree: " + ddrFreeSize);
        debugPrintln("baseAddr: " + ddrFreeBaseAddr);
        this.useCompress = getTempDivisionSize(ddrFreeSize);
      } 
      boolean isPci = isPci(parts);
      for (int index = 1; index < partsSize; index++) {
        PartitionItem partitionItem = parts.get(index);
        FlashType flashType = partitionItem.getFlashType();
        if (FlashType.isEmmcOrUfs(flashType) || flashType == FlashType.ssd) {
          if (flashType == FlashType.ssd && isPci) {
            if (!sendSsdByPci(parts))
              return false; 
            isPci = false;
          } 
          result = burnEachZipForEmmc(uimonitor, parts, index);
        } else {
          result = burnEachPartForNandOrSpi(uimonitor, parts, index);
        } 
        if (!result) {
          errorCode[0] = BurnStatus.BURN_PARTITION_FAILED.getErrorCode();
          return result;
        } 
      } 
      sendCommandToSetMac();
      boolean isResetJtag = ((FastbootView.isChipBranchSeries2() || FastbootView.isChipBranchSeries0()) && (curTransferWay == TransferWay.JTAG || curTransferWay == TransferWay.JTAGAndNet || curTransferWay == TransferWay.JTAGAndSerial));
      if (!isResetJtag) {
        String resetCommand = "reset";
        sendCommandNoReturnValue(resetCommand);
      } 
    } 
    infoln("Partition burnt completed!");
    return result;
  }
}
